==> distilabel-1.2.0.tar.gz: distilabel-1.2.0/docs/sections/community/index.md <==
---
hide:
    - toc
    - footer
---

We are an open-source community-driven project not only focused on building a great product but also on building a great community, where you can get support, share your experiences, and contribute to the project! We would love to hear from you and help you get started with distilabel.

<div class="grid cards" markdown>

-   __Slack__

    ---

    In our Slack you can get direct support from the community.


    [:octicons-arrow-right-24: Slack ↗](https://join.slack.com/t/rubrixworkspace/shared_invite/zt-whigkyjn-a3IUJLD7gDbTZ0rKlvcJ5g)

-   __Community Meetup__

    ---

    We host bi-weekly community meetups where you can listen in or present your work.

    [:octicons-arrow-right-24: Community Meetup ↗](https://lu.ma/argilla-event-calendar)

-   __Changelog__

    ---

    The changelog is where you can find the latest updates and changes to the distilabel project.

    [:octicons-arrow-right-24: Changelog ↗](https://github.com/argilla-io/distilabel/releases)

-   __Roadmap__

    ---

    We love to discuss our plans with the community. Feel encouraged to participate in our roadmap discussions.

    [:octicons-arrow-right-24: Roadmap ↗](https://github.com/orgs/argilla-io/projects/15)

</div>

## Badges

If you build something cool with `distilabel` consider adding one of these badges to your dataset or model card.

    [<img src="https://raw.githubusercontent.com/argilla-io/distilabel/main/docs/assets/distilabel-badge-light.png" alt="Built with Distilabel" width="200" height="32"/>](https://github.com/argilla-io/distilabel)

[<img src="https://raw.githubusercontent.com/argilla-io/distilabel/main/docs/assets/distilabel-badge-light.png" alt="Built with Distilabel" width="200" height="32"/>](https://github.com/argilla-io/distilabel)

    [<img src="https://raw.githubusercontent.com/argilla-io/distilabel/main/docs/assets/distilabel-badge-dark.png" alt="Built with Distilabel" width="200" height="32"/>](https://github.com/argilla-io/distilabel)

[<img src="https://raw.githubusercontent.com/argilla-io/distilabel/main/docs/assets/distilabel-badge-dark.png" alt="Built with Distilabel" width="200" height="32"/>](https://github.com/argilla-io/distilabel)

## Contribute

To directly contribute with `distilabel`, check our [good first issues](https://github.com/argilla-io/distilabel/issues?q=is%3Aissue+is%3Aopen+label%3A%22good+first+issue%22) or [open a new one](https://github.com/argilla-io/distilabel/issues/new/choose).

==> distilabel-1.3.0.tar.gz: distilabel-1.3.0/docs/sections/community/index.md <==
---
hide:
    - toc
    - footer
---

We are an open-source community-driven project not only focused on building a great product but also on building a great community, where you can get support, share your experiences, and contribute to the project! We would love to hear from you and help you get started with distilabel.

<div class="grid cards" markdown>

-   __Discord__

    ---

    In our Discord channels (#argilla-general and #argilla-help), you can get direct support from the community.


    [:octicons-arrow-right-24: Discord ↗](http://hf.co/join/discord)

-   __Community Meetup__

    ---

    We host bi-weekly community meetups where you can listen in or present your work.

    [:octicons-arrow-right-24: Community Meetup ↗](https://lu.ma/argilla-event-calendar)

-   __Changelog__

    ---

    The changelog is where you can find the latest updates and changes to the distilabel project.

    [:octicons-arrow-right-24: Changelog ↗](https://github.com/argilla-io/distilabel/releases)

-   __Roadmap__

    ---

    We love to discuss our plans with the community. Feel encouraged to participate in our roadmap discussions.

    [:octicons-arrow-right-24: Roadmap ↗](https://github.com/orgs/argilla-io/projects/15)

</div>

## Badges

If you build something cool with `distilabel` consider adding one of these badges to your dataset or model card.

    [<img src="https://raw.githubusercontent.com/argilla-io/distilabel/main/docs/assets/distilabel-badge-light.png" alt="Built with Distilabel" width="200" height="32"/>](https://github.com/argilla-io/distilabel)

[<img src="https://raw.githubusercontent.com/argilla-io/distilabel/main/docs/assets/distilabel-badge-light.png" alt="Built with Distilabel" width="200" height="32"/>](https://github.com/argilla-io/distilabel)

    [<img src="https://raw.githubusercontent.com/argilla-io/distilabel/main/docs/assets/distilabel-badge-dark.png" alt="Built with Distilabel" width="200" height="32"/>](https://github.com/argilla-io/distilabel)

[<img src="https://raw.githubusercontent.com/argilla-io/distilabel/main/docs/assets/distilabel-badge-dark.png" alt="Built with Distilabel" width="200" height="32"/>](https://github.com/argilla-io/distilabel)

## Contribute

To directly contribute with `distilabel`, check our [good first issues](https://github.com/argilla-io/distilabel/issues?q=is%3Aissue+is%3Aopen+label%3A%22good+first+issue%22) or [open a new one](https://github.com/argilla-io/distilabel/issues/new/choose).
